@@ -219,6 +219,11 @@ class CoverageTest(
                     self.fail("None of the missing choices matched %r" % missing_formatted)
 
         if arcs is not None:
+            # print("Possible arcs:")
+            # print(" expected:", arcs)
+            # print(" actual:", analysis.arc_possibilities())
+            # print("Executed:")
+            # print(" actual:", sorted(set(analysis.arcs_executed())))
             with self.delayed_assertions():
                 self.assert_equal_arcs(
                     arcs, analysis.arc_possibilities(),
@@ -504,5 +509,5 @@ def command_line(args):
 
 
 def xfail(condition, reason):
-    """A decorator to mark as test as expected to fail."""
+    """A decorator to mark a test as expected to fail."""
     return pytest.mark.xfail(condition, reason=reason, strict=True)
