@@ -1,16 +1,16 @@
 # Licensed under the Apache License: http://www.apache.org/licenses/LICENSE-2.0
-# For details: https://bitbucket.org/ned/coveragepy/src/default/NOTICE.txt
+# For details: https://github.com/nedbat/coveragepy/blob/master/NOTICE.txt
 
 """Helpers for coverage.py tests."""
 
 import glob
-import itertools
 import os
 import re
 import shutil
 import subprocess
 import sys
 
+import mock
 from unittest_mixins import ModuleCleaner
 
 from coverage import env
@@ -106,6 +106,13 @@ def re_line(text, pat):
     return lines[0]
 
 
+def remove_files(*patterns):
+    """Remove all files that match any of the patterns."""
+    for pattern in patterns:
+        for fname in glob.glob(pattern):
+            os.remove(fname)
+
+
 class SuperModuleCleaner(ModuleCleaner):
     """Remember the state of sys.modules and restore it later."""
 
@@ -122,9 +129,96 @@ class SuperModuleCleaner(ModuleCleaner):
         # Also have to clean out the .pyc file, since the timestamp
         # resolution is only one second, a changed file might not be
         # picked up.
-        for pyc in itertools.chain(glob.glob('*.pyc'), glob.glob('*$py.class')):
-            os.remove(pyc)
+        remove_files("*.pyc", "*$py.class")
         if os.path.exists("__pycache__"):
             shutil.rmtree("__pycache__")
 
         invalidate_import_caches()
+
+
+# Map chars to numbers for arcz_to_arcs
+_arcz_map = {'.': -1}
+_arcz_map.update(dict((c, ord(c) - ord('0')) for c in '123456789'))
+_arcz_map.update(dict(
+    (c, 10 + ord(c) - ord('A')) for c in 'ABCDEFGHIJKLMNOPQRSTUVWXYZ'
+))
+
+def arcz_to_arcs(arcz):
+    """Convert a compact textual representation of arcs to a list of pairs.
+
+    The text has space-separated pairs of letters.  Period is -1, 1-9 are
+    1-9, A-Z are 10 through 36.  The resulting list is sorted regardless of
+    the order of the input pairs.
+
+    ".1 12 2." --> [(-1,1), (1,2), (2,-1)]
+
+    Minus signs can be included in the pairs:
+
+    "-11, 12, 2-5" --> [(-1,1), (1,2), (2,-5)]
+
+    """
+    arcs = []
+    for pair in arcz.split():
+        asgn = bsgn = 1
+        if len(pair) == 2:
+            a, b = pair
+        else:
+            assert len(pair) == 3
+            if pair[0] == '-':
+                _, a, b = pair
+                asgn = -1
+            else:
+                assert pair[1] == '-'
+                a, _, b = pair
+                bsgn = -1
+        arcs.append((asgn * _arcz_map[a], bsgn * _arcz_map[b]))
+    return sorted(arcs)
+
+
+_arcz_unmap = {val: ch for ch, val in _arcz_map.items()}
+
+def _arcs_to_arcz_repr_one(num):
+    """Return an arcz form of the number `num`, or "?" if there is none."""
+    if num == -1:
+        return "."
+    z = ""
+    if num < 0:
+        z += "-"
+        num *= -1
+    z += _arcz_unmap.get(num, "?")
+    return z
+
+
+def arcs_to_arcz_repr(arcs):
+    """Convert a list of arcs to a readable multi-line form for asserting.
+
+    Each pair is on its own line, with a comment showing the arcz form,
+    to make it easier to decode when debugging test failures.
+
+    """
+    repr_list = []
+    for a, b in arcs:
+        line = repr((a, b))
+        line += " # "
+        line += _arcs_to_arcz_repr_one(a)
+        line += _arcs_to_arcz_repr_one(b)
+        repr_list.append(line)
+    return "\n".join(repr_list) + "\n"
+
+
+def without_module(using_module, missing_module_name):
+    """
+    Hide a module for testing.
+
+    Use this in a test function to make an optional module unavailable during
+    the test::
+
+        with without_module(product.something, 'toml'):
+            use_toml_somehow()
+
+    Arguments:
+        using_module: a module in which to hide `missing_module_name`.
+        missing_module_name (str): the name of the module to hide.
+
+    """
+    return mock.patch.object(using_module, missing_module_name, None)
