@@ -495,7 +495,8 @@ class HtmlTest(HtmlTestHelpers, CoverageTest):
         self.assert_exists("htmlcov/index.html")
         self.assert_exists("htmlcov/other_py.html")
 
-    def test_report_skip_covered_no_branches(self):
+    def make_main_and_not_covered(self):
+        """Helper to create files for skip_covered scenarios."""
         self.make_file("main_file.py", """
             import not_covered
 
@@ -507,11 +508,29 @@ class HtmlTest(HtmlTestHelpers, CoverageTest):
             def not_covered():
                 print("n")
         """)
+
+    def test_report_skip_covered(self):
+        self.make_main_and_not_covered()
         self.run_coverage(htmlargs=dict(skip_covered=True))
         self.assert_exists("htmlcov/index.html")
         self.assert_doesnt_exist("htmlcov/main_file_py.html")
         self.assert_exists("htmlcov/not_covered_py.html")
 
+    def test_html_skip_covered(self):
+        self.make_main_and_not_covered()
+        self.make_file(".coveragerc", "[html]\nskip_covered = True")
+        self.run_coverage()
+        self.assert_exists("htmlcov/index.html")
+        self.assert_doesnt_exist("htmlcov/main_file_py.html")
+        self.assert_exists("htmlcov/not_covered_py.html")
+
+    def test_report_skip_covered_branches(self):
+        self.make_main_and_not_covered()
+        self.run_coverage(covargs=dict(branch=True), htmlargs=dict(skip_covered=True))
+        self.assert_exists("htmlcov/index.html")
+        self.assert_doesnt_exist("htmlcov/main_file_py.html")
+        self.assert_exists("htmlcov/not_covered_py.html")
+
     def test_report_skip_covered_100(self):
         self.make_file("main_file.py", """
             def normal():
@@ -522,24 +541,8 @@ class HtmlTest(HtmlTestHelpers, CoverageTest):
         self.assertEqual(res, 100.0)
         self.assert_doesnt_exist("htmlcov/main_file_py.html")
 
-    def test_report_skip_covered_branches(self):
-        self.make_file("main_file.py", """
-            import not_covered
-
-            def normal():
-                print("z")
-            normal()
-        """)
-        self.make_file("not_covered.py", """
-            def not_covered():
-                print("n")
-        """)
-        self.run_coverage(covargs=dict(branch=True), htmlargs=dict(skip_covered=True))
-        self.assert_exists("htmlcov/index.html")
-        self.assert_doesnt_exist("htmlcov/main_file_py.html")
-        self.assert_exists("htmlcov/not_covered_py.html")
-
-    def test_report_skip_empty_files(self):
+    def make_init_and_main(self):
+        """Helper to create files for skip_empty scenarios."""
         self.make_file("submodule/__init__.py", "")
         self.make_file("main_file.py", """
             import submodule
@@ -548,11 +551,22 @@ class HtmlTest(HtmlTestHelpers, CoverageTest):
                 print("z")
             normal()
         """)
+
+    def test_report_skip_empty(self):
+        self.make_init_and_main()
         self.run_coverage(htmlargs=dict(skip_empty=True))
         self.assert_exists("htmlcov/index.html")
         self.assert_exists("htmlcov/main_file_py.html")
         self.assert_doesnt_exist("htmlcov/submodule___init___py.html")
 
+    def test_html_skip_empty(self):
+        self.make_init_and_main()
+        self.make_file(".coveragerc", "[html]\nskip_empty = True")
+        self.run_coverage()
+        self.assert_exists("htmlcov/index.html")
+        self.assert_exists("htmlcov/main_file_py.html")
+        self.assert_doesnt_exist("htmlcov/submodule___init___py.html")
+
 
 class HtmlStaticFileTest(CoverageTest):
     """Tests of the static file copying for the HTML report."""
@@ -938,23 +952,41 @@ assert len(math) == 18
 
         cov = coverage.Coverage(config_file="partial.ini")
         partial = self.start_import_stop(cov, "partial")
-        cov.html_report(partial, directory="out/partial")
 
-        compare_html(gold_path("html/partial"), "out/partial")
-        contains(
-            "out/partial/partial_py.html",
-            '<p id="t4" class="par run show_par">',
-            '<p id="t7" class="run">',
-            # The "if 0" and "if 1" statements are optimized away.
-            '<p id="t10" class="pln">',
-            # The "raise ZeroDivisionError" is excluded by regex in the .ini.
-            '<p id="t17" class="exc show_exc">',
-        )
-        contains(
-            "out/partial/index.html",
-            '<a href="partial_py.html">partial.py</a>',
-            '<span class="pc_cov">91%</span>'
-        )
+        if env.PYBEHAVIOR.pep626:
+            cov.html_report(partial, directory="out/partial_626")
+            compare_html(gold_path("html/partial_626"), "out/partial_626")
+            contains(
+                "out/partial_626/partial_py.html",
+                '<p id="t4" class="par run show_par">',
+                '<p id="t7" class="run">',
+                # The "if 0" and "if 1" statements are marked as run.
+                '<p id="t10" class="run">',
+                # The "raise ZeroDivisionError" is excluded by regex in the .ini.
+                '<p id="t17" class="exc show_exc">',
+            )
+            contains(
+                "out/partial_626/index.html",
+                '<a href="partial_py.html">partial.py</a>',
+                '<span class="pc_cov">87%</span>'
+            )
+        else:
+            cov.html_report(partial, directory="out/partial")
+            compare_html(gold_path("html/partial"), "out/partial")
+            contains(
+                "out/partial/partial_py.html",
+                '<p id="t4" class="par run show_par">',
+                '<p id="t7" class="run">',
+                # The "if 0" and "if 1" statements are optimized away.
+                '<p id="t10" class="pln">',
+                # The "raise ZeroDivisionError" is excluded by regex in the .ini.
+                '<p id="t17" class="exc show_exc">',
+            )
+            contains(
+                "out/partial/index.html",
+                '<a href="partial_py.html">partial.py</a>',
+                '<span class="pc_cov">91%</span>'
+            )
 
     def test_styled(self):
         self.make_file("a.py", """\
