@@ -171,11 +171,11 @@ class PythonParserTest(CoverageTest):
             def func(x=25):
                 return 26
             """)
-        raw_statements = set([3, 4, 5, 6, 8, 9, 10, 13, 15, 16, 17, 20, 22, 23, 25, 26])
+        raw_statements = {3, 4, 5, 6, 8, 9, 10, 13, 15, 16, 17, 20, 22, 23, 25, 26}
         if env.PYBEHAVIOR.trace_decorated_def:
             raw_statements.update([11, 19])
         self.assertEqual(parser.raw_statements, raw_statements)
-        self.assertEqual(parser.statements, set([8]))
+        self.assertEqual(parser.statements, {8})
 
     def test_class_decorator_pragmas(self):
         parser = self.parse_source("""\
@@ -188,8 +188,8 @@ class PythonParserTest(CoverageTest):
                 def __init__(self):
                     self.x = 8
             """)
-        self.assertEqual(parser.raw_statements, set([1, 2, 3, 5, 6, 7, 8]))
-        self.assertEqual(parser.statements, set([1, 2, 3]))
+        self.assertEqual(parser.raw_statements, {1, 2, 3, 5, 6, 7, 8})
+        self.assertEqual(parser.statements, {1, 2, 3})
 
     def test_empty_decorated_function(self):
         parser = self.parse_source("""\
@@ -214,7 +214,7 @@ class PythonParserTest(CoverageTest):
             expected_arcs = set(arcz_to_arcs(".1 14 48 8.  .2 2.  -8A A-8"))
             expected_exits = {1: 1, 2: 1, 4: 1, 8: 1, 10: 1}
 
-        if (not env.PYPY) and (env.PYVERSION >= (3, 7, 0, 'beta', 5)):
+        if env.PYBEHAVIOR.docstring_only_function:
             # 3.7 changed how functions with only docstrings are numbered.
             expected_arcs.update(set(arcz_to_arcs("-46 6-4")))
             expected_exits.update({6: 1})
@@ -330,70 +330,73 @@ class ParserMissingArcDescriptionTest(CoverageTest):
                     try:
                         if something(4):
                             break
+                        elif something(6):
+                            x = 7
                         else:
-                            if something(7):
+                            if something(9):
                                 continue
                             else:
                                 continue
-                        if also_this(11):
-                            return 12
+                        if also_this(13):
+                            return 14
                         else:
-                            raise Exception(14)
+                            raise Exception(16)
                     finally:
-                        this_thing(16)
-                that_thing(17)
+                        this_thing(18)
+                that_thing(19)
             """)
         if env.PYBEHAVIOR.finally_jumps_back:
             self.assertEqual(
-                parser.missing_arc_description(16, 5),
-                "line 16 didn't jump to line 5, because the break on line 5 wasn't executed"
+                parser.missing_arc_description(18, 5),
+                "line 18 didn't jump to line 5, because the break on line 5 wasn't executed"
             )
             self.assertEqual(
-                parser.missing_arc_description(5, 17),
-                "line 5 didn't jump to line 17, because the break on line 5 wasn't executed"
+                parser.missing_arc_description(5, 19),
+                "line 5 didn't jump to line 19, because the break on line 5 wasn't executed"
             )
             self.assertEqual(
-                parser.missing_arc_description(16, 8),
-                "line 16 didn't jump to line 8, because the continue on line 8 wasn't executed"
+                parser.missing_arc_description(18, 10),
+                "line 18 didn't jump to line 10, because the continue on line 10 wasn't executed"
             )
             self.assertEqual(
-                parser.missing_arc_description(8, 2),
-                "line 8 didn't jump to line 2, because the continue on line 8 wasn't executed"
+                parser.missing_arc_description(10, 2),
+                "line 10 didn't jump to line 2, because the continue on line 10 wasn't executed"
             )
             self.assertEqual(
-                parser.missing_arc_description(16, 12),
-                "line 16 didn't jump to line 12, because the return on line 12 wasn't executed"
+                parser.missing_arc_description(18, 14),
+                "line 18 didn't jump to line 14, because the return on line 14 wasn't executed"
             )
             self.assertEqual(
-                parser.missing_arc_description(12, -1),
-                "line 12 didn't return from function 'function', "
-                    "because the return on line 12 wasn't executed"
+                parser.missing_arc_description(14, -1),
+                "line 14 didn't return from function 'function', "
+                    "because the return on line 14 wasn't executed"
             )
             self.assertEqual(
-                parser.missing_arc_description(16, -1),
-                "line 16 didn't except from function 'function', "
-                    "because the raise on line 14 wasn't executed"
+                parser.missing_arc_description(18, -1),
+                "line 18 didn't except from function 'function', "
+                    "because the raise on line 16 wasn't executed"
             )
         else:
             self.assertEqual(
-                parser.missing_arc_description(16, 17),
-                "line 16 didn't jump to line 17, because the break on line 5 wasn't executed"
+                parser.missing_arc_description(18, 19),
+                "line 18 didn't jump to line 19, because the break on line 5 wasn't executed"
             )
             self.assertEqual(
-                parser.missing_arc_description(16, 2),
-                "line 16 didn't jump to line 2, "
-                    "because the continue on line 8 wasn't executed"
+                parser.missing_arc_description(18, 2),
+                "line 18 didn't jump to line 2, "
+                    "because the continue on line 10 wasn't executed"
                     " or "
-                    "the continue on line 10 wasn't executed"
+                    "the continue on line 12 wasn't executed"
             )
             self.assertEqual(
-                parser.missing_arc_description(16, -1),
-                "line 16 didn't except from function 'function', "
-                    "because the raise on line 14 wasn't executed"
+                parser.missing_arc_description(18, -1),
+                "line 18 didn't except from function 'function', "
+                    "because the raise on line 16 wasn't executed"
                 " or "
-                "line 16 didn't return from function 'function', "
-                    "because the return on line 12 wasn't executed"
+                "line 18 didn't return from function 'function', "
+                    "because the return on line 14 wasn't executed"
             )
+
     def test_missing_arc_descriptions_bug460(self):
         parser = self.parse_text(u"""\
             x = 1
@@ -463,7 +466,7 @@ class ParserFileTest(CoverageTest):
             """)
 
         parser = self.parse_file("normal.py")
-        self.assertEqual(parser.statements, set([1]))
+        self.assertEqual(parser.statements, {1})
 
         self.make_file("abrupt.py", """\
             out, err = subprocess.Popen(
@@ -476,4 +479,4 @@ class ParserFileTest(CoverageTest):
             self.assertEqual(f.read()[-1], ")")
 
         parser = self.parse_file("abrupt.py")
-        self.assertEqual(parser.statements, set([1]))
+        self.assertEqual(parser.statements, {1})
