@@ -400,12 +400,12 @@ class GoodFileTracerTest(FileTracerTest):
         # have 7 lines in it.  If render() was called with line number 4,
         # then the plugin will claim that lines 4 and 5 were executed.
         analysis = cov._analyze("foo_7.html")
-        self.assertEqual(analysis.statements, set([1, 2, 3, 4, 5, 6, 7]))
+        self.assertEqual(analysis.statements, {1, 2, 3, 4, 5, 6, 7})
         # Plugins don't do branch coverage yet.
         self.assertEqual(analysis.has_arcs(), True)
         self.assertEqual(analysis.arc_possibilities(), [])
 
-        self.assertEqual(analysis.missing, set([1, 2, 3, 6, 7]))
+        self.assertEqual(analysis.missing, {1, 2, 3, 6, 7})
 
     def test_plugin2_with_text_report(self):
         self.make_render_and_caller()
@@ -522,6 +522,8 @@ class GoodFileTracerTest(FileTracerTest):
             'Name              Stmts   Miss  Cover   Missing',
             '-----------------------------------------------',
             'unsuspecting.py       6      3    50%   2, 4, 6',
+            '-----------------------------------------------',
+            'TOTAL                 6      3    50%',
             ]
         self.assertEqual(expected, report)
         self.assertEqual(total, 50)
@@ -553,7 +555,7 @@ class GoodFileTracerTest(FileTracerTest):
 
             class MyReporter(coverage.FileReporter):
                 def lines(self):
-                    return set([99, 999, 9999])
+                    return {99, 999, 9999}
 
             def coverage_init(reg, options):
                 reg.add_file_tracer(Plugin())
